==> haskell-text-binary-0.2.1.1-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-text-binary.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: text-binary
version: 0.2.1.1
id: text-binary-0.2.1.1-Ixe45FI2fTB8kwbVqDai0g
key: text-binary-0.2.1.1-Ixe45FI2fTB8kwbVqDai0g
license: BSD2
maintainer: waszczuk.kuba@gmail.com
stability: provisional
homepage: https://github.com/kawu/text-binary
synopsis: Binary instances for text types
description:
    A compatibility layer providing Binary instances for strict
    and lazy text types for versions older than 1.2.1 of
    <https://hackage.haskell.org/package/text>.
category: Data
author: Jakub Waszczuk
exposed: True
indefinite: False
exposed-modules:
    Data.Text.Binary
abi: a14c670a3deccb290cfcf087234d1e73
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/text-binary-0.2.1.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/text-binary-0.2.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/text-binary-0.2.1.1
hs-libraries: HStext-binary-0.2.1.1-Ixe45FI2fTB8kwbVqDai0g
depends:
    base-4.10.1.0 binary-0.8.5.1 text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             binary-0.8.5.1=efb65bc450356b9ea572733928ffb43f
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=0c99dc42f18da90e6080c205f57d188a
haddock-interfaces: /usr/share/doc/haskell-text-binary/html/text-binary.haddock
haddock-html: /usr/share/doc/haskell-text-binary/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-binary-0.2.1.1-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-text-binary.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: text-binary
version: 0.2.1.1
id: text-binary-0.2.1.1-HRlId0E5Ru65sAuueVFeUA
key: text-binary-0.2.1.1-HRlId0E5Ru65sAuueVFeUA
license: BSD2
maintainer: waszczuk.kuba@gmail.com
stability: provisional
homepage: https://github.com/kawu/text-binary
synopsis: Binary instances for text types
description:
    A compatibility layer providing Binary instances for strict
    and lazy text types for versions older than 1.2.1 of
    <https://hackage.haskell.org/package/text>.
category: Data
author: Jakub Waszczuk
exposed: True
indefinite: False
exposed-modules:
    Data.Text.Binary
abi: e8c2e01e677313e799438daeaaf8e40d
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/text-binary-0.2.1.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/text-binary-0.2.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/text-binary-0.2.1.1
hs-libraries: HStext-binary-0.2.1.1-HRlId0E5Ru65sAuueVFeUA
depends:
    base-4.10.1.0 binary-0.8.5.1 text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             binary-0.8.5.1=efb65bc450356b9ea572733928ffb43f
             text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj=d51c5ac73448d7d6c9cbe4dedb95457e
haddock-interfaces: /usr/share/doc/haskell-text-binary/html/text-binary.haddock
haddock-html: /usr/share/doc/haskell-text-binary/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
